@@ -9,11 +9,14 @@
 #define __nss_h_
 
 /* The private macro _NSS_CUSTOMIZED is for NSS internal use only. */
-#if defined(NSS_ALLOW_UNSUPPORTED_CRITICAL)
+//#if defined(NSS_ALLOW_UNSUPPORTED_CRITICAL)
+//#define _NSS_CUSTOMIZED " (Customized build)"
+//#else
+//#define _NSS_CUSTOMIZED
+//#endif
+
+// UXP: custom-patched
 #define _NSS_CUSTOMIZED " (Customized build)"
-#else
-#define _NSS_CUSTOMIZED
-#endif
 
 /*
  * NSS's major version, minor version, patch level, build number, and whether
@@ -22,11 +25,11 @@
  * The format of the version string should be
  *     "<major version>.<minor version>[.<patch level>[.<build number>]][ <ECC>][ <Beta>]"
  */
-#define NSS_VERSION "3.52.9" _NSS_CUSTOMIZED
+#define NSS_VERSION "3.79.4.1" _NSS_CUSTOMIZED
 #define NSS_VMAJOR 3
-#define NSS_VMINOR 52
-#define NSS_VPATCH 9
-#define NSS_VBUILD 0
+#define NSS_VMINOR 79
+#define NSS_VPATCH 4
+#define NSS_VBUILD 1
 #define NSS_BETA PR_FALSE
 
 #ifndef RC_INVOKED
@@ -299,6 +302,8 @@ SECStatus NSS_UnregisterShutdown(NSS_ShutdownFunc sFunc, void *appData);
  * old NSS versions.  This option might be removed in the future NSS
  * releases; don't rely on it. */
 #define __NSS_PKCS12_DECODE_FORCE_UNICODE 0x00c
+#define NSS_DEFAULT_LOCKS 0x00d /* lock default values */
+#define NSS_DEFAULT_SSL_LOCK 1  /* lock the ssl default values */
 
 /*
  * Set and get global options for the NSS library.
